@@ -76,6 +76,8 @@ static int isCloseOutFile = 0;	/* " */
 #endif				/* " */
 int gifSize = 0;		/* " #bytes comprising gif */
 int maxgifSize = MAXGIFSZ;	/* " max #bytes written to OutBuffer */
+extern int  iscachecontenttype;	/* " true to cache mime content-type */
+extern char contenttype[2048];	/* " content-type:, etc. buffer */
 
 /* used when writing to a file bitwise */
 static Byte Buffer[256];        /* there must be one more than `needed' */
@@ -196,7 +198,10 @@ Create(const char *filename)
       if ( *filename != '\000' )		/* " */
 	{ if ((OutFile = fopen(filename, "wb")) == NULL)
 	    return GIF_ERRCREATE;
-	  isCloseOutFile = 1; }			/* (added by j.forkosh) */
+	  isCloseOutFile = 1;			/* (added by j.forkosh) */
+          if ( iscachecontenttype )		/* " cache headers in file */
+            if ( *contenttype != '\000' )	/* " have headers in buffer*/
+              fputs(contenttype,OutFile); }	/* " write buffered headers*/
       else					/* " */
 	OutBuffer = (Byte *)filename;		/* " */
     return GIF_OK;
@@ -324,6 +329,7 @@ InitBitFile(void)
 {
     Buffer[Index = 0] = 0;
     BitsLeft = 8;
+    memset(Buffer,0,256);
 }
 
 
@@ -354,6 +360,7 @@ ResetOutBitFile(void)
 
         Buffer[Index = 0] = 0;
         BitsLeft = 8;
+        memset(Buffer,0,256);
     }
     return 0;
 }
@@ -389,6 +396,7 @@ WriteBits(int bits, int numbits)
 
             Buffer[Index = 0] = 0;
             BitsLeft = 8;
+            memset(Buffer,0,256);
         }
 
         /* now take care of the two specialcases */
@@ -469,6 +477,9 @@ AllocStrtab(void)
         FreeStrtab();
         return GIF_OUTMEM;
     }
+    memset(StrChr,0,MAXSTR*sizeof(Byte));
+    memset(StrNxt,0,MAXSTR*sizeof(Word));
+    memset(StrHsh,0,HASHSIZE*sizeof(Word));
     return GIF_OK;
 }
 
